@@ -1,6 +1,6 @@
 #!/bin/sh
 
-export HOME=$ADTTMP
+export HOME=$AUTOPKGTEST_TMP
 export PIP_DISABLE_PIP_VERSION_CHECK=1
 
 cd $HOME
